@@ -28,6 +28,7 @@ class PCRClient:
                  short_udid: str = '',
                  viewer_id: str = '',
                  server_id: int = 0,
+                 version: str = '',
                  proxy: dict = None):
         # check arguments
         if playerprefs:
@@ -46,7 +47,7 @@ class PCRClient:
         log.debug(f'cert setup: server_id = {server_id}, viewer_id = {viewer_id}, short_udid = {short_udid}')
         log.debug(f'udid = {udid}')
 
-        self.sec = PCRSecret(udid, short_udid, viewer_id)
+        self.sec = PCRSecret(udid, short_udid, viewer_id, version)
         self.server_id = server_id
         self.proxy = proxy or {}
 
@@ -56,10 +57,10 @@ class PCRClient:
 
         self.api_root = _API_ROOT[server_id - 1]
 
-    async def register(self, udid=str(uuid.uuid1())):
+    async def register(self, udid=str(uuid.uuid1()), version: str = ''):
         log.warning(f'registering now, udid={udid}')
 
-        self.sec = PCRSecret(udid, '0', '0')
+        self.sec = PCRSecret(udid, '0', '0', version)
         await self.call.tool.check_agreement().exec()
 
         gh = {'Upgrade-Insecure-Requests': '1',
@@ -74,7 +75,7 @@ class PCRClient:
 
         r = (await self.call.tool.signup().exec(no_headers=False))['data_headers']
 
-        self.sec = PCRSecret(r['udid'], r['short_udid'], r['viewer_id'])
+        self.sec = PCRSecret(r['udid'], r['short_udid'], r['viewer_id'], version)
         log.info(f"{r['viewer_id']} {r['short_udid']} {r['udid']}")
 
     async def req(self, api: str, params: dict, no_headers=True):
@@ -93,6 +94,13 @@ class PCRClient:
         self.game_data = await self.call.load.index().exec()
         self.token = ''.join(random.choices(string.digits, k=16))
 
+    async def pass_tutorial(self):
+        # tutorial
+        steps = [1, 2, 3, 4, 5, 6, 7, 20, 30, 40, 50, 60, 100]
+        for i in steps:
+            await self.call.tutorial.update_step(i, 0).exec(1)
+            log.info(f'tutorial step: {i}')
+
     async def donate_equipment(self):
         clan_id = (await self.call.clan.info().exec())['clan']['detail']['clan_id']
         chats = await self.call.clan.chat_info_list(clan_id).exec()
@@ -208,6 +216,21 @@ class _ReqBase(_Req):
     def tool(self):
         return _ReqTool(self)
 
+    @property
+    def chara_fortune(self):
+        return _ReqCharaFortune(self)
+
+
+class _ReqCharaFortune(_Req):
+    def __init__(self, r: _Req):
+        super().__init__()
+        self.client = r.client
+        self.api = r.api + '/chara_fortune'
+
+    @end_point
+    def draw(self, fortune_id: int, unit_id: int):  # anniversary
+        self.params = {'fortune_id': fortune_id, 'unit_id': unit_id}
+
 
 class _ReqTool(_Req):
     def __init__(self, r: _Req):
@@ -251,6 +274,24 @@ class _ReqPresent(_Req):
 
 
 class _ReqStory(_Req):
+    """
+    check: enter the scene
+    start: finish reading
+
+    makeup of the story_id:
+    e.g. 2001000:  2 | 0 | 01|000
+                   a | b | c | d
+        a: type
+            1: chara
+            2: mainline
+            3: guild
+            4: extra
+            9: special event(such as kaiser_battle or anniversary)
+        b: episode(only available in mainline story, a==2)
+        c: chapter(when a!=2, usually used with b)
+        d: story
+    """
+
     def __init__(self, r: _Req):
         super().__init__()
         self.client = r.client
@@ -264,6 +305,10 @@ class _ReqStory(_Req):
     def start(self, story_id: int):
         self.params = {'story_id': story_id}
 
+    @end_point
+    def force_release(self, story_group_id: int):
+        self.params = {'story_group_id': story_group_id}
+
 
 class _ReqEvent(_Req):
     def __init__(self, r: _Req):
